@@ -114,9 +114,11 @@ public:
     void TestBug11421();
     void TestBug13277();
     void TestBug13554();
+    void TestBug20410();
 
     void TestAddLikelySubtags();
     void TestMinimizeSubtags();
+    void TestAddLikelyAndMinimizeSubtags();
 
     void TestForLanguageTag();
     void TestToLanguageTag();
@@ -124,8 +126,17 @@ public:
     void TestMoveAssign();
     void TestMoveCtor();
 
+    void TestBug20407iVariantPreferredValue();
+
     void TestBug13417VeryLongLanguageTag();
 
+    void TestBug11053UnderlineTimeZone();
+
+    void TestUnd();
+    void TestUndScript();
+    void TestUndRegion();
+    void TestUndCAPI();
+
 private:
     void _checklocs(const char* label,
                     const char* req,
