@@ -215,7 +215,6 @@ UObject *UObjectTest::testClassNoClassID(UObject *obj, const char *className, co
 #include "rbt_data.h"
 #include "nultrans.h"
 #include "anytrans.h"
-#include "digitlst.h"
 #include "esctrn.h"
 #include "funcrepl.h"
 #include "servnotf.h"
@@ -273,9 +272,11 @@ UObject *UObjectTest::testClassNoClassID(UObject *obj, const char *className, co
 #include "unicode/idna.h"
 #include "unicode/locdspnm.h"
 #include "unicode/locid.h"
+#include "unicode/measunit.h"
 #include "unicode/msgfmt.h"
 #include "unicode/normlzr.h"
 #include "unicode/normalizer2.h"
+#include "unicode/nounit.h"
 #include "unicode/numfmt.h"
 #include "unicode/parsepos.h"
 #include "unicode/plurrule.h"
@@ -292,6 +293,7 @@ UObject *UObjectTest::testClassNoClassID(UObject *obj, const char *className, co
 #include "unicode/stsearch.h"
 #include "unicode/tblcoll.h"
 #include "unicode/timezone.h"
+#include "unicode/tmunit.h"
 #include "unicode/translit.h"
 #include "unicode/uchriter.h"
 #include "unicode/uloc.h"
@@ -370,9 +372,13 @@ void UObjectTest::testIDs()
     TESTCLASSID_DEFAULT(FieldPosition);
     TESTCLASSID_DEFAULT(Formattable);
 
-    static const UChar SMALL_STR[] = {0x51, 0x51, 0x51, 0}; // "QQQ"
+    TESTCLASSID_FACTORY(MeasureUnit, MeasureUnit::createMeter(status));
+    TESTCLASSID_FACTORY(NoUnit, NoUnit::percent().clone());
+    TESTCLASSID_FACTORY(TimeUnit, TimeUnit::createInstance(TimeUnit::UTIMEUNIT_YEAR, status));
+    static const UChar SMALL_STR[] = u"QQQ";
     TESTCLASSID_CTOR(CurrencyAmount, (1.0, SMALL_STR, status));
     TESTCLASSID_CTOR(CurrencyUnit, (SMALL_STR, status));
+
     TESTCLASSID_NONE_FACTORY(LocaleDisplayNames, LocaleDisplayNames::createInstance("de"));
     TESTCLASSID_FACTORY_HIDDEN(CurrencyFormat, MeasureFormat::createCurrencyFormat(Locale::getUS(), status));
     TESTCLASSID_FACTORY(GregorianCalendar, Calendar::createInstance(Locale("@calendar=gregorian"), status));
@@ -489,7 +495,7 @@ void UObjectTest::testIDs()
     TESTCLASSID_NONE_CTOR(AlphabeticIndex, (Locale::getEnglish(), status));
 #endif
 
-#if UOBJTEST_DUMP_IDS
+#ifdef UOBJTEST_DUMP_IDS
     int i;
     for(i=0;i<ids_count;i++) {
         char junk[800];
